PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - t -

- target() : Connection, Segment_25, WideSegment_25
- target_2() : Segment_25, WideSegment_25
- targetCap() : WideSegment_25
- targetComponent() : Connection
- targetPin() : Connection
- terminate() : Window
- toBool() : py::Object
- toDouble() : py::Object
- Token() : Token
- tokenize() : DSNParserBase
- toLong() : py::Object
- toString() : py::Object
- touchesEndToEnd() : Track
- touchesEndToStart() : Track
- touchesStartToEnd() : Track
- touchesStartToStart() : Track
- Trace() : Logger
- traceWidth() : NetOverrides
- Track() : Track
- tracksBbox() : Connection
- transform() : AShape, CircleEx, IsoRectEx, Object, PolygonEx, TriangleEx, WideSegment_25
- transformPreservesType() : AShape, CircleEx, IsoRectEx
- transformType() : AShape, IsoRectEx
- translate() : AShape, CircleEx, IsoRectEx, Object, PolygonEx, TriangleEx, WideSegment_25
- TriangleEx() : TriangleEx
- TriList() : TriList
- tryStartExclusiveTask() : IUIApplication
- turning() : Path